(function(e){typeof define==`function`&&define.amd?define([],e):e()})(function(){var e=((e,t)=>()=>(t||e((t={exports:{}}).exports,t),t.exports))(((e,t)=>{t.exports={}}));function t(e,t,r,i){if(!1===t||t==null||!t&&(e===`class`||e===`style`))return``;if(!0===t)return` `+(i?e:e+`="`+e+`"`);var a=typeof t;return a!==`object`&&a!==`function`||typeof t.toJSON!=`function`||(t=t.toJSON()),typeof t==`string`||(t=JSON.stringify(t),r||t.indexOf(`"`)===-1)?(r&&(t=n(t)),` `+e+`="`+t+`"`):` `+e+`='`+t.replace(/'/g,`&#39;`)+`'`}function n(e){var t=``+e,n=r.exec(t);if(!n)return e;var i,a,o,s=``;for(i=n.index,a=0;i<t.length;i++){switch(t.charCodeAt(i)){case 34:o=`&quot;`;break;case 38:o=`&amp;`;break;case 60:o=`&lt;`;break;case 62:o=`&gt;`;break;default:continue}a!==i&&(s+=t.substring(a,i)),a=i+1,s+=o}return a===i?s:s+t.substring(a,i)}var r=/["&<>]/;function i(t,n,r,a){if(!(t instanceof Error))throw t;if(!(typeof window>`u`&&n||a))throw t.message+=` on line `+r,t;var o,s,c,l;try{a||=e().readFileSync(n,{encoding:`utf8`}),o=3,s=a.split(`
`),c=Math.max(r-o,0),l=Math.min(s.length,r+o)}catch(e){t.message+=` - could not read from `+n+` (`+e.message+`)`,i(t,null,r);return}o=s.slice(c,l).map(function(e,t){var n=t+c+1;return(n==r?`  > `:`    `)+n+`| `+e}).join(`
`),t.path=n;try{t.message=(n||`Pug`)+`:`+r+`
`+o+`

`+t.message}catch{}throw t}function a(e){var n=``,r,a;try{var o=e||{};(function(e){a=1,r=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/assetstoreButtonsExtension.pug`,n+=`<div class="g-assetstore-button-container">`,a=2,r=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/assetstoreButtonsExtension.pug`,n=n+`<a`+(` class="g-view-imports btn btn-sm btn-primary"`+t(`href`,e,!0,!1))+`>`,a=3,r=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/assetstoreButtonsExtension.pug`,n+=`<i class="icon-link-ext"></i>`,a=4,r=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/assetstoreButtonsExtension.pug`,n+=` View past imports</a></div>`}).call(this,`importsPageLink`in o?o.importsPageLink:typeof importsPageLink<`u`?importsPageLink:void 0)}catch(e){i(e,r,a)}return n}function o(e,t,n,r){if(!1===t||t==null||!t&&(e===`class`||e===`style`))return``;if(!0===t)return` `+(r?e:e+`="`+e+`"`);var i=typeof t;return i!==`object`&&i!==`function`||typeof t.toJSON!=`function`||(t=t.toJSON()),typeof t==`string`||(t=JSON.stringify(t),n||t.indexOf(`"`)===-1)?(n&&(t=s(t)),` `+e+`="`+t+`"`):` `+e+`='`+t.replace(/'/g,`&#39;`)+`'`}function s(e){var t=``+e,n=c.exec(t);if(!n)return e;var r,i,a,o=``;for(r=n.index,i=0;r<t.length;r++){switch(t.charCodeAt(r)){case 34:a=`&quot;`;break;case 38:a=`&amp;`;break;case 60:a=`&lt;`;break;case 62:a=`&gt;`;break;default:continue}i!==r&&(o+=t.substring(i,r)),i=r+1,o+=a}return i===r?o:o+t.substring(i,r)}var c=/["&<>]/;function l(t,n,r,i){if(!(t instanceof Error))throw t;if(!(typeof window>`u`&&n||i))throw t.message+=` on line `+r,t;var a,o,s,c;try{i||=e().readFileSync(n,{encoding:`utf8`}),a=3,o=i.split(`
`),s=Math.max(r-a,0),c=Math.min(o.length,r+a)}catch(e){t.message+=` - could not read from `+n+` (`+e.message+`)`,l(t,null,r);return}a=o.slice(s,c).map(function(e,t){var n=t+s+1;return(n==r?`  > `:`    `)+n+`| `+e}).join(`
`),t.path=n;try{t.message=(n||`Pug`)+`:`+r+`
`+a+`

`+t.message}catch{}throw t}function u(e){var t=``,n,r;try{var i=e||{};(function(e,i,a,c,l,u,d,f,p,m,h,g){r=1,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<div class="it-controls">`,r=2,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,g?(r=12,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,u?(r=17,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+`<a`+(` class="g-view-imports btn btn-sm btn-primary"`+o(`href`,`#assetstore/${u}/imports`,!0,!1))+`>`,r=18,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<i class="icon-link-ext"></i>`,r=19,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`View all past Imports</a>`):(r=13,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<a class="g-view-imports btn btn-sm btn-primary" href="#assetstore/all_imports">`,r=14,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<i class="icon-link-ext"></i>`,r=15,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`View all past Imports</a>`)):(r=3,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,u?(r=8,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+`<a`+(` class="g-view-imports btn btn-sm btn-primary"`+o(`href`,`#assetstore/${u}/unique_imports`,!0,!1))+`>`,r=9,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<i class="icon-link-ext"></i>`,r=10,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`View unique past Imports</a>`):(r=4,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<a class="g-view-imports btn btn-sm btn-primary" href="#assetstore/all_unique_imports">`,r=5,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<i class="icon-link-ext"></i>`,r=6,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`View unique past Imports</a>`)),t+=`</div>`,r=20,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<table class="g-imports-list-table">`,r=21,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`;var l=!1,c=!1,a=!1,m=[],h=!1;r=27,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,(function(){var t=f;if(typeof t.length==`number`)for(var o=0,s=t.length;o<s;o++){var u=t[o];r=28,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,(u.get(`params`).fileIncludeRegex||u.get(`params`).fileExcludeRegex)&&(r=29,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,l=i),r=30,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,u.get(`params`).leafFoldersAsItems&&u.get(`params`).leafFoldersAsItems!==`false`&&(r=31,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,c=!0),r=32,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,e.keys(u.get(`params`)).forEach(e=>{[`importPath`,`destinationId`,`leafFoldersAsItems`,`progress`,`fileIncludeRegex`,`fileExcludeRegex`,`params`].indexOf(e)<0&&m.indexOf(e)<0&&m.push(e)}),r=33,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,u.get(`_count`)&&(r=34,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,h=!0),r=35,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,u.get(`params`).importPath&&(r=36,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,a=!0)}else{var s=0;for(var o in t){s++;var u=t[o];r=28,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,(u.get(`params`).fileIncludeRegex||u.get(`params`).fileExcludeRegex)&&(r=29,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,l=i),r=30,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,u.get(`params`).leafFoldersAsItems&&u.get(`params`).leafFoldersAsItems!==`false`&&(r=31,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,c=!0),r=32,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,e.keys(u.get(`params`)).forEach(e=>{[`importPath`,`destinationId`,`leafFoldersAsItems`,`progress`,`fileIncludeRegex`,`fileExcludeRegex`,`params`].indexOf(e)<0&&m.indexOf(e)<0&&m.push(e)}),r=33,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,u.get(`_count`)&&(r=34,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,h=!0),r=35,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,u.get(`params`).importPath&&(r=36,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,a=!0)}}}).call(this),r=37,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<thead>`,r=38,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<tr>`,r=39,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<th>`,r=39,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`Actions</th>`,r=40,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,h&&(r=41,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<th>`,r=41,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`Repeats</th>`),r=42,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<th>`,r=42,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`Started</th>`,r=43,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<th>`,r=43,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`Ended</th>`,r=44,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<th>`,r=44,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`Assetstore Name</th>`,r=45,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,a&&(r=46,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<th>`,r=46,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`Import Path</th>`),r=48,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<th>`,r=48,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`Destination Path</th>`,r=49,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,c&&(r=50,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<th>`,r=50,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`Leafed Folders</th>`),r=51,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,l&&(r=52,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<th>`,r=52,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`File Include Regex</th>`,r=53,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<th>`,r=53,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`File Exclude Regex</th>`),r=54,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,(function(){var e=m;if(typeof e.length==`number`)for(var i=0,a=e.length;i<a;i++){var o=e[i];r=55,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<th>`,r=55,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+s(o.replace(/([A-Z])/g,` $1`).replace(/^./,e=>e.toUpperCase())??``)+`</th>`}else{var a=0;for(var i in e){a++;var o=e[i];r=55,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<th>`,r=55,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+s(o.replace(/([A-Z])/g,` $1`).replace(/^./,e=>e.toUpperCase())??``)+`</th>`}}}).call(this),t+=`</tr></thead>`,r=56,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<tbody>`,r=57,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,(function(){var e=f;if(typeof e.length==`number`)for(var i=0,u=e.length;i<u;i++){var g=e[i];r=58,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<tr>`,r=59,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<td>`,r=60,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,d.includes(g.get(`assetstoreId`))&&(r=61,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<div class="g-imports-buttons">`,r=62,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+`<button`+(` class="re-import-btn btn btn-sm btn-success"`+o(`index`,i,!0,!1)+o(`disabled`,g.get(`_destinationPath`)==`does not exist`,!0,!1))+`>`,r=63,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<i class="icon-cw"></i>`,r=64,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=` Re-Import</button>`,r=65,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+`<button`+(` class="re-import-edit-btn btn btn-sm btn-primary"`+o(`index`,i,!0,!1)+` data-toggle="tooltip" title="Edit Import Parameters"`)+`>`,r=66,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<i class="icon-pencil"></i></button></div>`),t+=`</td>`,r=67,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,h&&(r=68,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+`<td`+(o(`data-id`,g.get(`_count`),!0,!1)+` data-toggle="tooltip"`+o(`title`,g.get(`_count`)===1?`Imported once`:`Imported ${g.get(`_count`)} times`,!0,!1))+`>`,r=69,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<span>`,r=69,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+s(g.get(`_count`)??``)+`</span></td>`),r=70,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+`<td`+(o(`data-id`,g.get(`started`),!0,!1)+` data-toggle="tooltip"`+o(`title`,g.get(`started`),!0,!1))+`>`,r=71,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<span>`,r=71,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+s(p(g.get(`started`)).format(`YYYY-MM-DD HH:mm:ss.SSS`)??``)+`</span></td>`,r=72,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+`<td`+(o(`data-id`,g.get(`ended`),!0,!1)+` data-toggle="tooltip"`+o(`title`,g.get(`ended`)||``,!0,!1))+`>`,r=73,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<span>`,r=73,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+s((g.get(`ended`)?p(g.get(`ended`)).format(`YYYY-MM-DD HH:mm:ss.SSS`):``)??``)+`</span></td>`,r=74,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+`<td`+(o(`data-id`,g.get(`_assetstoreName`),!0,!1)+` data-toggle="tooltip"`+o(`title`,g.get(`_assetstoreName`),!0,!1))+`>`,r=75,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<span>`,r=75,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+s(g.get(`_assetstoreName`)??``)+`</span></td>`,r=76,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,a&&(r=77,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+`<td`+(o(`data-id`,g.get(`params`).importPath,!0,!1)+` data-toggle="tooltip"`+o(`title`,g.get(`params`).importPath,!0,!1))+`>`,r=78,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<span>`,r=78,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+s((g.get(`params`).importPath||``).replaceAll(/(?!^)\//g,`/­`)??``)+`</span></td>`),r=79,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+`<td`+(o(`data-id`,g.get(`params`).destinationId,!0,!1)+` data-toggle="tooltip"`+o(`title`,g.get(`_destinationPath`)+`
`+g.get(`params`).destinationId,!0,!1))+`>`,r=80,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<span>`,r=80,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+s((g.get(`_destinationPath`)||``).replaceAll(/(?!^)\//g,`/­`)??``)+`</span></td>`,r=81,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,c&&(r=82,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<td>`,r=83,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<span>`,r=83,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+s(g.get(`params`).leafFoldersAsItems??``)+`</span></td>`),r=84,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,l&&(r=85,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<td>`,r=86,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<span>`,r=86,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+s(g.get(`params`).fileIncludeRegex??``)+`</span></td>`,r=87,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<td>`,r=88,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<span>`,r=88,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+s(g.get(`params`).fileExcludeRegex??``)+`</span></td>`),r=89,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,(function(){var e=m;if(typeof e.length==`number`)for(var i=0,a=e.length;i<a;i++){var o=e[i];r=90,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<td>`,r=91,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<span>`,r=91,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+s(g.get(`params`)[o]??``)+`</span></td>`}else{var a=0;for(var i in e){a++;var o=e[i];r=90,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<td>`,r=91,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<span>`,r=91,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+s(g.get(`params`)[o]??``)+`</span></td>`}}}).call(this),t+=`</tr>`}else{var u=0;for(var i in e){u++;var g=e[i];r=58,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<tr>`,r=59,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<td>`,r=60,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,d.includes(g.get(`assetstoreId`))&&(r=61,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<div class="g-imports-buttons">`,r=62,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+`<button`+(` class="re-import-btn btn btn-sm btn-success"`+o(`index`,i,!0,!1)+o(`disabled`,g.get(`_destinationPath`)==`does not exist`,!0,!1))+`>`,r=63,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<i class="icon-cw"></i>`,r=64,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=` Re-Import</button>`,r=65,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+`<button`+(` class="re-import-edit-btn btn btn-sm btn-primary"`+o(`index`,i,!0,!1)+` data-toggle="tooltip" title="Edit Import Parameters"`)+`>`,r=66,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<i class="icon-pencil"></i></button></div>`),t+=`</td>`,r=67,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,h&&(r=68,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+`<td`+(o(`data-id`,g.get(`_count`),!0,!1)+` data-toggle="tooltip"`+o(`title`,g.get(`_count`)===1?`Imported once`:`Imported ${g.get(`_count`)} times`,!0,!1))+`>`,r=69,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<span>`,r=69,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+s(g.get(`_count`)??``)+`</span></td>`),r=70,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+`<td`+(o(`data-id`,g.get(`started`),!0,!1)+` data-toggle="tooltip"`+o(`title`,g.get(`started`),!0,!1))+`>`,r=71,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<span>`,r=71,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+s(p(g.get(`started`)).format(`YYYY-MM-DD HH:mm:ss.SSS`)??``)+`</span></td>`,r=72,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+`<td`+(o(`data-id`,g.get(`ended`),!0,!1)+` data-toggle="tooltip"`+o(`title`,g.get(`ended`)||``,!0,!1))+`>`,r=73,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<span>`,r=73,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+s((g.get(`ended`)?p(g.get(`ended`)).format(`YYYY-MM-DD HH:mm:ss.SSS`):``)??``)+`</span></td>`,r=74,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+`<td`+(o(`data-id`,g.get(`_assetstoreName`),!0,!1)+` data-toggle="tooltip"`+o(`title`,g.get(`_assetstoreName`),!0,!1))+`>`,r=75,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<span>`,r=75,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+s(g.get(`_assetstoreName`)??``)+`</span></td>`,r=76,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,a&&(r=77,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+`<td`+(o(`data-id`,g.get(`params`).importPath,!0,!1)+` data-toggle="tooltip"`+o(`title`,g.get(`params`).importPath,!0,!1))+`>`,r=78,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<span>`,r=78,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+s((g.get(`params`).importPath||``).replaceAll(/(?!^)\//g,`/­`)??``)+`</span></td>`),r=79,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+`<td`+(o(`data-id`,g.get(`params`).destinationId,!0,!1)+` data-toggle="tooltip"`+o(`title`,g.get(`_destinationPath`)+`
`+g.get(`params`).destinationId,!0,!1))+`>`,r=80,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<span>`,r=80,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+s((g.get(`_destinationPath`)||``).replaceAll(/(?!^)\//g,`/­`)??``)+`</span></td>`,r=81,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,c&&(r=82,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<td>`,r=83,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<span>`,r=83,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+s(g.get(`params`).leafFoldersAsItems??``)+`</span></td>`),r=84,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,l&&(r=85,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<td>`,r=86,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<span>`,r=86,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+s(g.get(`params`).fileIncludeRegex??``)+`</span></td>`,r=87,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<td>`,r=88,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<span>`,r=88,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+s(g.get(`params`).fileExcludeRegex??``)+`</span></td>`),r=89,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,(function(){var e=m;if(typeof e.length==`number`)for(var i=0,a=e.length;i<a;i++){var o=e[i];r=90,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<td>`,r=91,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<span>`,r=91,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+s(g.get(`params`)[o]??``)+`</span></td>`}else{var a=0;for(var i in e){a++;var o=e[i];r=90,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<td>`,r=91,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<span>`,r=91,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t=t+s(g.get(`params`)[o]??``)+`</span></td>`}}}).call(this),t+=`</tr>`}}}).call(this),t+=`</tbody></table>`,r=93,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/importList.pug`,t+=`<div class="g-imports-pagination"></div>`}).call(this,`Object`in i?i.Object:typeof Object<`u`?Object:void 0,`True`in i?i.True:typeof True<`u`?True:void 0,`anyImportPath`in i?i.anyImportPath:typeof anyImportPath<`u`?anyImportPath:void 0,`anyLeafed`in i?i.anyLeafed:typeof anyLeafed<`u`?anyLeafed:void 0,`anyRegex`in i?i.anyRegex:typeof anyRegex<`u`?anyRegex:void 0,`assetstoreId`in i?i.assetstoreId:typeof assetstoreId<`u`?assetstoreId:void 0,`assetstores`in i?i.assetstores:typeof assetstores<`u`?assetstores:void 0,`imports`in i?i.imports:typeof imports<`u`?imports:void 0,`moment`in i?i.moment:typeof moment<`u`?moment:void 0,`otherParams`in i?i.otherParams:typeof otherParams<`u`?otherParams:void 0,`showCount`in i?i.showCount:typeof showCount<`u`?showCount:void 0,`unique`in i?i.unique:typeof unique<`u`?unique:void 0)}catch(e){l(e,n,r)}return t}var d=girder.$,f=girder.views.widgets.PaginateWidget,p=girder.collections.Collection,m=girder.models.AssetstoreModel,{SORT_DESC:h}=girder.constants,g=girder.moment,_=girder.views.View,v=girder.router,{restRequest:y}=girder.rest,b=_.extend({events:{"click .re-import-btn":function(e){let t=Number(d(e.currentTarget).attr(`index`)),n=this.imports[t];if(n===void 0)return;let r=new m({_id:n.get(`assetstoreId`)}),i=n.get(`params`).destinationType,a=n.get(`params`).destinationId;r.off(`g:imported`).on(`g:imported`,function(){v.navigate(i+`/`+a,{trigger:!0})},this).on(`g:error`,function(e){this.$(`.g-validation-failed-message`).text(e.responseJSON.message)},this),r.once(`g:fetched`,()=>{r.import(n.get(`params`))}).fetch()},"click .re-import-edit-btn":function(e){let t=Number(d(e.currentTarget).attr(`index`)),n=this.imports[t];n!==void 0&&((e,t)=>{new m({_id:e}).once(`g:fetched`,()=>{v.navigate(`assetstore/${e}/re-import/${t}`,{trigger:!0})}).fetch()})(n.get(`assetstoreId`),n.get(`_id`))}},initialize({id:e,unique:t}){this._unique=t,this._assetstoreId=e,this.imports=[];let n=e?`${e}/imports`:`all_imports`;this.collection=new p,this.collection.altUrl=`assetstore/${n}`,this.collection.sortField=`started`,this.collection.sortDir=h,this.collection.params={unique:t||!1},this.listenTo(this.collection,`update reset`,this._updateData),this.paginateWidget=new f({collection:this.collection,parentView:this}),y({url:`assetstore`,data:{limit:0}}).done(e=>{this.assetstores=e.map(e=>e._id),this.collection.fetch({},!0)})},_updateData(){this.imports=this.collection.toArray(),this.render()},render(){return this.$el.html(u({imports:this.imports,assetstores:this.assetstores,moment:g,unique:this._unique,assetstoreId:this._assetstoreId})),this.$el.tooltip(),this.paginateWidget.setElement(this.$(`.g-imports-pagination`)).render(),this}}),x=girder.models.AssetstoreModel,S=girder.views.View,{AssetstoreType:C}=girder.constants,w=girder.router,T=girder.events,{restRequest:E}=girder.rest,D=(e,t)=>{T.trigger(`g:alert`,{icon:`cancel`,text:`Could not re-import: ${t}`,type:`danger`}),w.navigate(`assetstore/${e}/import`,{trigger:!0,replace:!0})},O=S.extend({initialize({assetstoreId:e,importId:t}){this.importId=t,this.assetstoreId=e,this.type=``,E({url:`assetstore/import/${t}`,error:null}).done(n=>{if(!n){D(this.assetstoreId,`Unable to find import ${t}`);return}this.import=n;let r=new x({_id:e});r.once(`g:fetched`,()=>{let e=r.get(`type`);e===C.FILESYSTEM?this.type=`filesystem`:e===C.S3?this.type=`s3`:e===C.DICOMWEB?this.type=`dwas`:e===C.GIRDER?this.type=`gas`:D(this.assetstoreId,`Unsupported assetstore type '${e}'`),this.render()}).fetch()}).fail(()=>{D(this.assetstoreId,`Unable to fetch base import information`)})},render(){let e=this.import.params,t=e.destinationId,n=e.destinationType,r=e.excludeExisting?`true`:`false`;return this.$(`#g-${this.type}-import-path`).val(e.importPath),this.$(`#g-${this.type}-import-dest-type`).val(n),this.$(`#g-${this.type}-import-dest-id`).val(t),this.$(`#g-${this.type}-import-leaf-items`).val(e.leafFoldersAsItems),this.$(`#g-${this.type}-import-exclude-existing`).val(r),this.type===`dwas`&&(this.$(`#g-${this.type}-import-filters`).val(e.filters),this.$(`#g-${this.type}-import-limit`).val(e.limit)),E({url:`resource/${t}/path`,method:`GET`,data:{type:n},error:null}).done(e=>{this.$(`#g-${this.type}-import-dest-id`).val(`${t} (${e})`)}).fail(()=>{this.$(`#g-${this.type}-import-dest-id`).val(``)}),this}});function k(e,t,n,r){if(!1===t||t==null||!t&&(e===`class`||e===`style`))return``;if(!0===t)return` `+(r?e:e+`="`+e+`"`);var i=typeof t;return i!==`object`&&i!==`function`||typeof t.toJSON!=`function`||(t=t.toJSON()),typeof t==`string`||(t=JSON.stringify(t),n||t.indexOf(`"`)===-1)?(n&&(t=A(t)),` `+e+`="`+t+`"`):` `+e+`='`+t.replace(/'/g,`&#39;`)+`'`}function A(e){var t=``+e,n=j.exec(t);if(!n)return e;var r,i,a,o=``;for(r=n.index,i=0;r<t.length;r++){switch(t.charCodeAt(r)){case 34:a=`&quot;`;break;case 38:a=`&amp;`;break;case 60:a=`&lt;`;break;case 62:a=`&gt;`;break;default:continue}i!==r&&(o+=t.substring(i,r)),i=r+1,o+=a}return i===r?o:o+t.substring(i,r)}var j=/["&<>]/;function M(t,n,r,i){if(!(t instanceof Error))throw t;if(!(typeof window>`u`&&n||i))throw t.message+=` on line `+r,t;var a,o,s,c;try{i||=e().readFileSync(n,{encoding:`utf8`}),a=3,o=i.split(`
`),s=Math.max(r-a,0),c=Math.min(o.length,r+a)}catch(e){t.message+=` - could not read from `+n+` (`+e.message+`)`,M(t,null,r);return}a=o.slice(s,c).map(function(e,t){var n=t+s+1;return(n==r?`  > `:`    `)+n+`| `+e}).join(`
`),t.path=n;try{t.message=(n||`Pug`)+`:`+r+`
`+a+`

`+t.message}catch{}throw t}function N(e){var t=``,n,r;try{var i=e||{};(function(e){r=1,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/excludeExistingInput.pug`,t+=`<div class="form-group">`,r=2,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/excludeExistingInput.pug`,t=t+`<label`+k(`for`,`g-`+e+`-import-exclude-existing`,!0,!1)+`>`,r=2,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/excludeExistingInput.pug`,t+=`Exclude Existing Files</label>`,r=3,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/excludeExistingInput.pug`,t=t+`<select`+(` class="form-control"`+k(`id`,`g-`+e+`-import-exclude-existing`,!0,!1))+`>`,r=4,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/excludeExistingInput.pug`,t+=`<option value="false">`,r=4,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/excludeExistingInput.pug`,t+=`False</option>`,r=5,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/excludeExistingInput.pug`,t+=`<option value="true">`,r=5,n=`/home/circleci/project/girder/plugins/import_tracker/girder_import_tracker/web_client/templates/excludeExistingInput.pug`,t+=`True</option></select></div>`}).call(this,`type`in i?i.type:typeof type<`u`?type:void 0)}catch(e){M(e,n,r)}return t}girder.events.on(`g:appload.before`,()=>{let e=girder.plugins.jobs.JobStatus,t=e.isCancelable;e.isCancelable=function(n){return[`assetstore_import`,`folder_move`].includes(n.get(`type`))?![e.CANCELED,e.SUCCESS,e.ERROR].includes(n.get(`status`)):t(n)}});var P=girder.$,{AssetstoresView:F,FilesystemImportView:I,S3ImportView:L}=girder.views.body,{CollectionModel:R,FolderModel:z,UserModel:B}=girder.models,{wrap:V}=girder.utilities.PluginUtils,H=girder.events,U=girder.router;V(F,`render`,function(e){e.call(this),window.setTimeout(()=>{this.$el.find(`.g-current-assetstores-container .g-body-title`).after(`<a class="g-view-imports btn btn-sm btn-primary" href="#assetstore/all_unique_imports"><i class="icon-link-ext"></i>View all past Imports</a>`);let e=this.collection;this.$(`.g-assetstore-import-button-container`).after(function(){return a({importsPageLink:`#assetstore/${e.get(P(this).closest(`.g-assetstore-buttons`).find(`[cid]`).attr(`cid`)).id}/unique_imports`})})},0)}),V(I,`render`,function(e){e.call(this),this.$(`.form-group`).last().after(N({type:`filesystem`}))}),V(L,`render`,function(e){e.call(this),this.$(`.form-group`).last().after(N({type:`s3`}))});var W=(e,t)=>{let n=e._browserWidgetView,r=e.$(`#g-${t}-import-dest-type`).val(),i=e.$(`#g-${t}-import-dest-id`).val().trim().split(/\s/)[0],a={collection:R,folder:z,user:B};if(i&&r in a){let e=new a[r]({_id:i});e.once(`g:fetched`,()=>{(!n.root||n.root.id!==e.id)&&(n.root=e,n._renderRootSelection())}).on(`g:error`,e=>{e.status===400&&H.trigger(`g:alert`,{icon:`cancel`,text:`No ${r.toUpperCase()} with ID ${i} found.`,type:`danger`,timeout:4e3})}).fetch({ignoreError:!0})}};V(I,`_openBrowser`,function(e){W(this,`filesystem`),e.call(this)}),V(L,`_openBrowser`,function(e){W(this,`s3`),e.call(this)});var G=(e,t)=>{let n=e.$(`#g-${t}-import-dest-id`).val().trim().split(/\s/)[0],r=e.$(`#g-${t}-import-dest-type`).val(),i={destinationId:n,destinationType:r,excludeExisting:e.$(`#g-${t}-import-exclude-existing`).val(),progress:!0};t===`filesystem`&&(i.leafFoldersAsItems=e.$(`#g-${t}-import-leaf-items`).val()),t===`dwas`?(i.filters=e.$(`#g-${t}-import-filters`).val().trim(),i.limit=e.$(`#g-${t}-import-limit`).val().trim()):i.importPath=e.$(`#g-${t}-import-path`).val().trim(),e.$(`.g-validation-failed-message`).empty(),e.$(`.g-submit-${t}-import`).addClass(`disabled`);let a=e.assetstore;a=a.off().on(`g:imported`,function(){U.navigate(r+`/`+n,{trigger:!0})},e).on(`g:error`,function(n){e.$(`.g-submit-${t}-import`).removeClass(`disabled`),e.$(`.g-validation-failed-message`).html(n.responseJSON.message)},e),a.import(i)};I.prototype.events[`submit .g-filesystem-import-form`]=function(e){e.preventDefault(),G(this,`filesystem`)},L.prototype.events[`submit .g-s3-import-form`]=function(e){e.preventDefault(),G(this,`s3`)},U.route(`assetstore/:id/imports`,`importsPage`,function(e){H.trigger(`g:navigateTo`,b,{id:e})}),U.route(`assetstore/:id/unique_imports`,`importsPage`,function(e){H.trigger(`g:navigateTo`,b,{id:e,unique:!0})}),U.route(`assetstore/all_imports`,`importsPage`,function(){H.trigger(`g:navigateTo`,b)}),U.route(`assetstore/all_unique_imports`,`importsPage`,function(){H.trigger(`g:navigateTo`,b,{unique:!0})}),U.route(`assetstore/:id/re-import/:prev`,`assetstoreImport`,function(e,t){H.trigger(`g:navigateTo`,O,{assetstoreId:e,importId:t}),F.import(e)})});